@@ -10,13 +10,13 @@ from inflection import pluralize
 from pandas.tseries.frequencies import to_offset
 from flask import request, current_app
 from flask_json import as_json
-from flask_principal import Permission, RoleNeed
 from flask_security import current_user
 import marshmallow
 
 from webargs.flaskparser import parser
 
-from flexmeasures.api.common.schemas.times import DurationField
+from flexmeasures.api.common.schemas.sensors import SensorField
+from flexmeasures.data.schemas.times import DurationField
 from flexmeasures.api.common.responses import (  # noqa: F401
     required_info_missing,
     invalid_horizon,
@@ -26,7 +26,6 @@ from flexmeasures.api.common.responses import (  # noqa: F401
     unapplicable_resolution,
     invalid_resolution_str,
     conflicting_resolutions,
-    invalid_sender,
     invalid_source,
     invalid_timezone,
     invalid_unit,
@@ -40,19 +39,30 @@ from flexmeasures.api.common.utils.api_utils import (
     parse_as_list,
     contains_empty_items,
     upsample_values,
-    get_generic_asset,
 )
+from flexmeasures.data import db
 from flexmeasures.data.models.data_sources import DataSource
-from flexmeasures.data.config import db
 from flexmeasures.data.services.users import get_users
 from flexmeasures.utils.time_utils import server_now
 
+"""
+This module has validators used by API endpoints <= 2.0 to describe
+acceptable parameters.
+We aim to make this module obsolete by using Marshmallow.
+Marshmallow is a better format to describe valid data.
+There is some actual logic in here, which we still need. It can usually be ported to Marshmallow validators.
+"""
+
 
 p = inflect.engine()
 
 
 def validate_user_sources(sources: Union[int, str, List[Union[int, str]]]) -> List[int]:
-    """Return a list of user source ids given a user id, a role name or a list thereof."""
+    """
+    Return a list of user-based data source ids, given:
+    - one or more user ids
+    - one or more account role names
+    """
     sources = (
         sources if isinstance(sources, list) else [sources]
     )  # Make sure sources is a list
@@ -68,8 +78,8 @@ def validate_user_sources(sources: Union[int, str, List[Union[int, str]]]) -> Li
             except TypeError:
                 current_app.logger.warning("Could not retrieve data source %s" % source)
                 pass
-        else:  # Parse as role name
-            user_ids = [user.id for user in get_users(source)]
+        else:  # Parse as account role name
+            user_ids = [user.id for user in get_users(account_role_name=source)]
             user_source_ids.extend(
                 [
                     params[0]
@@ -163,9 +173,9 @@ def valid_sensor_units(sensor: str) -> List[str]:
     """
     if sensor == "temperature":
         return ["°C", "0C"]
-    elif sensor == "radiation":
+    elif sensor == "irradiance":
         return ["kW/m²", "kW/m2"]
-    elif sensor == "wind_speed":
+    elif sensor == "wind speed":
         return ["m/s"]
     else:
         raise NotImplementedError(
@@ -261,7 +271,7 @@ def optional_user_sources_accepted(
         }
 
     The source ids then include the user's own id,
-    and ids of other users that are registered as a Prosumer and/or Energy Service Company.
+    and ids of other users whose organisation account is registered as a Prosumer and/or Energy Service Company.
     """
 
     def wrapper(fn):
@@ -736,11 +746,13 @@ def units_accepted(quantity: str, *units: str):
     return wrapper
 
 
-def post_data_checked_for_required_resolution(entity_type):  # noqa: C901
+def post_data_checked_for_required_resolution(
+    entity_type: str, fm_scheme: str
+):  # noqa: C901
     """Decorator which checks that a POST request receives time series data with the event resolutions
-    required by the sensor (asset). It sets the "resolution" keyword argument.
-    If the resolution in the data is a multiple of the asset resolution, values are upsampled to the asset resolution.
-    Finally, this decorator also checks if all assets have the same event_resolution and complains otherwise.
+    required by the sensor. It sets the "resolution" keyword argument.
+    If the resolution in the data is a multiple of the sensor resolution, values are upsampled to the sensor resolution.
+    Finally, this decorator also checks if all sensors have the same event_resolution and complains otherwise.
 
     The resolution of the data is inferred from the duration and the number of values.
     Therefore, the decorator should follow after the values_required, period_required and assets_required decorators.
@@ -788,30 +800,33 @@ def post_data_checked_for_required_resolution(entity_type):  # noqa: C901
                 (kwargs["start"] + kwargs["duration"]) - kwargs["start"]
             ) / len(kwargs["value_groups"][0])
 
-            # Finding the required resolution for assets affected in this request
+            # Finding the required resolution for sensors affected in this request
             required_resolution = None
-            last_asset = None
+            last_sensor = None
             for asset_group in kwargs["generic_asset_name_groups"]:
                 for asset_descriptor in asset_group:
-                    # Getting the asset
-                    generic_asset = get_generic_asset(asset_descriptor, entity_type)
-                    if generic_asset is None:
+                    # Getting the sensor
+                    sensor = SensorField(entity_type, fm_scheme).deserialize(
+                        asset_descriptor
+                    )
+                    if sensor is None:
                         return unrecognized_asset(
                             f"Failed to look up asset by {asset_descriptor}"
                         )
-                    # Complain if assets don't all require the same resolution
+                    # Complain if sensors don't all require the same resolution
                     if (
                         required_resolution is not None
-                        and generic_asset.event_resolution != required_resolution
+                        and sensor.event_resolution != required_resolution
                     ):
                         return conflicting_resolutions(
-                            f"Cannot send data for both {generic_asset} and {last_asset}."
+                            f"Cannot send data for both {sensor} and {last_sensor}."
                         )
-                    # Setting the resolution & remembering last looked-at asset
-                    required_resolution = generic_asset.event_resolution
-                    last_asset = generic_asset
+                    # Setting the resolution & remembering last looked-at sensor
+                    required_resolution = sensor.event_resolution
+                    last_sensor = sensor
 
             # if inferred resolution is a multiple from required_solution, we can upsample_values
+            # todo: next line fails on sensors with 0 resolution
             if inferred_resolution % required_resolution == timedelta(hours=0):
                 for i in range(len(kwargs["value_groups"])):
                     kwargs["value_groups"][i] = upsample_values(
@@ -837,15 +852,15 @@ def post_data_checked_for_required_resolution(entity_type):  # noqa: C901
     return wrapper
 
 
-def get_data_downsampling_allowed(entity_type):
+def get_data_downsampling_allowed(entity_type: str, fm_scheme: str):
     """Decorator which allows downsampling of data which a GET request returns.
     It checks for a form parameter "resolution".
-    If that is given and is a multiple of the asset's event_resolution,
+    If that is given and is a multiple of the sensor's event_resolution,
     downsampling is performed on the data. This is done by setting the "resolution"
     keyword parameter, which is obeyed by collect_time_series_data and used
     in resampling.
 
-    The original resolution of the data is the event_resolution of the asset.
+    The original resolution of the data is the event_resolution of the sensor.
     Therefore, the decorator should follow after the assets_required decorator.
 
     Example:
@@ -876,17 +891,19 @@ def get_data_downsampling_allowed(entity_type):
                 ds_resolution = parse_duration(form["resolution"])
                 if ds_resolution is None:
                     return invalid_resolution_str(form["resolution"])
-                # Check if the resolution can be applied to all assets (if it is a multiple
+                # Check if the resolution can be applied to all sensors (if it is a multiple
                 # of the event_resolution(s) and thus downsampling is possible)
                 for asset_group in kwargs["generic_asset_name_groups"]:
                     for asset_descriptor in asset_group:
-                        generic_asset = get_generic_asset(asset_descriptor, entity_type)
-                        if generic_asset is None:
+                        sensor = SensorField(entity_type, fm_scheme).deserialize(
+                            asset_descriptor
+                        )
+                        if sensor is None:
                             return unrecognized_asset()
-                        asset_resolution = generic_asset.event_resolution
-                        if ds_resolution % asset_resolution != timedelta(minutes=0):
+                        sensor_resolution = sensor.event_resolution
+                        if ds_resolution % sensor_resolution != timedelta(minutes=0):
                             return unapplicable_resolution(
-                                f"{isodate.duration_isoformat(asset_resolution)} or a multiple hereof."
+                                f"{isodate.duration_isoformat(sensor_resolution)} or a multiple hereof."
                             )
                 kwargs["resolution"] = to_offset(
                     isodate.parse_duration(form["resolution"])
@@ -897,46 +914,3 @@ def get_data_downsampling_allowed(entity_type):
         return decorated_service
 
     return wrapper
-
-
-def usef_roles_accepted(*usef_roles):
-    """Decorator which specifies that a user must have at least one of the
-    specified USEF roles (or must be an admin). Example:
-
-        @app.route('/postMeterData')
-        @roles_accepted('Prosumer', 'MDC')
-        def post_meter_data():
-            return 'Meter data posted'
-
-    The current user must have either the `Prosumer` role or `MDC` role in
-    order to use the service.
-    And finally, users with the anonymous user role are never accepted.
-
-    :param usef_roles: The possible roles.
-    """
-
-    def wrapper(fn):
-        @wraps(fn)
-        @as_json
-        def decorated_service(*args, **kwargs):
-            perm = Permission(*[RoleNeed(role) for role in usef_roles])
-            if current_user.has_role(
-                "anonymous"
-            ):  # TODO: this role needs to go, we should not mix permissive and restrictive roles
-                current_app.logger.warning(
-                    "Anonymous user is not accepted for this service"
-                )
-                return invalid_sender("anonymous user", "non-anonymous user")
-            elif perm.can() or current_user.has_role("admin"):
-                return fn(*args, **kwargs)
-            else:
-                current_app.logger.warning(
-                    "User does not have necessary authorization for this service"
-                )
-                return invalid_sender(
-                    [role.name for role in current_user.roles], *usef_roles
-                )
-
-        return decorated_service
-
-    return wrapper
