@@ -6,7 +6,6 @@ import pytest
 import pytz
 import timely_beliefs as tb
 
-from flexmeasures.data.models.assets import Asset, Power
 from flexmeasures.data.models.data_sources import DataSource
 from flexmeasures.data.models.time_series import Sensor, TimedBelief
 from flexmeasures.data.queries.utils import (
@@ -39,23 +38,27 @@ from flexmeasures.data.queries.utils import (
         # ),  # test empty BeliefsDataFrame  # todo: uncomment when this if fixed: https://github.com/pandas-dev/pandas/issues/30517
     ],
 )
-def test_collect_power(db, app, query_start, query_end, num_values):
-    wind_device_1 = Asset.query.filter_by(name="wind-asset-1").one_or_none()
-    data = Power.query.filter(Power.asset_id == wind_device_1.id).all()
+def test_collect_power(db, app, query_start, query_end, num_values, setup_test_data):
+    wind_device_1 = Sensor.query.filter_by(name="wind-asset-1").one_or_none()
+    data = TimedBelief.query.filter(TimedBelief.sensor_id == wind_device_1.id).all()
     print(data)
-    bdf: tb.BeliefsDataFrame = Power.collect(
-        wind_device_1.name, (query_start, query_end)
+    bdf: tb.BeliefsDataFrame = TimedBelief.search(
+        wind_device_1.name,
+        event_starts_after=query_start,
+        event_ends_before=query_end,
     )
     print(bdf)
     assert (
         bdf.index.names[0] == "event_start"
     )  # first index level of collect function should be event_start, so that df.loc[] refers to event_start
     assert pd.api.types.is_timedelta64_dtype(
-        bdf.index.get_level_values("belief_horizon")
+        bdf.convert_index_from_belief_time_to_horizon().index.get_level_values(
+            "belief_horizon"
+        )
     )  # dtype of belief_horizon is timedelta64[ns], so the minimum horizon on an empty BeliefsDataFrame is NaT instead of NaN
     assert len(bdf) == num_values
-    for v1, v2 in zip(bdf.values, data):
-        assert abs(v1[0] - v2.value) < 10 ** -6
+    for v1, v2 in zip(bdf["event_value"].tolist(), data):
+        assert abs(v1 - v2.event_value) < 10 ** -6
 
 
 @pytest.mark.parametrize(
@@ -88,11 +91,15 @@ def test_collect_power(db, app, query_start, query_end, num_values):
     ],
 )
 def test_collect_power_resampled(
-    db, app, query_start, query_end, resolution, num_values
+    db, app, query_start, query_end, resolution, num_values, setup_test_data
 ):
-    wind_device_1 = Asset.query.filter_by(name="wind-asset-1").one_or_none()
-    bdf: tb.BeliefsDataFrame = Power.collect(
-        wind_device_1.name, (query_start, query_end), resolution=resolution
+    wind_device_1 = Sensor.query.filter_by(name="wind-asset-1").one_or_none()
+    bdf: tb.BeliefsDataFrame = TimedBelief.search(
+        wind_device_1.name,
+        event_starts_after=query_start,
+        event_ends_before=query_end,
+        resolution=resolution,
+        most_recent_beliefs_only=True,
     )
     print(bdf)
     assert len(bdf) == num_values
@@ -204,17 +211,19 @@ def test_multiplication_with_both_empty_dataframe():
     pd.testing.assert_frame_equal(df, df_compare)
 
 
-def test_simplify_index():
+@pytest.mark.parametrize("check_empty_frame", [True, False])
+def test_simplify_index(setup_test_data, check_empty_frame):
     """Check whether simplify_index retains the event resolution."""
-    wind_device_1 = Asset.query.filter_by(name="wind-asset-1").one_or_none()
-    bdf: tb.BeliefsDataFrame = Power.collect(
+    wind_device_1 = Sensor.query.filter_by(name="wind-asset-1").one_or_none()
+    bdf: tb.BeliefsDataFrame = TimedBelief.search(
         wind_device_1.name,
-        (
-            datetime(2015, 1, 1, tzinfo=pytz.utc),
-            datetime(2015, 1, 2, tzinfo=pytz.utc),
-        ),
+        event_starts_after=datetime(2015, 1, 1, tzinfo=pytz.utc),
+        event_ends_before=datetime(2015, 1, 2, tzinfo=pytz.utc),
         resolution=timedelta(minutes=15),
-    )
+    ).convert_index_from_belief_time_to_horizon()
+    if check_empty_frame:
+        # We empty the BeliefsDataFrame, which retains the metadata such as sensor and resolution
+        bdf = bdf.iloc[0:0, :]
     df = simplify_index(bdf)
     assert df.event_resolution == timedelta(minutes=15)
 
@@ -222,29 +231,33 @@ def test_simplify_index():
 def test_query_beliefs(setup_beliefs):
     """Check various ways of querying for beliefs."""
     sensor = Sensor.query.filter_by(name="epex_da").one_or_none()
-    source = DataSource.query.filter_by(name="Seita").one_or_none()
+    source = DataSource.query.filter_by(name="ENTSO-E").one_or_none()
     bdfs = [
-        TimedBelief.search(sensor, source=source),
-        sensor.search_beliefs(source=source),
-        tb.BeliefsDataFrame(sensor.beliefs),  # doesn't allow filtering
+        TimedBelief.search(sensor, source=source, most_recent_beliefs_only=False),
+        TimedBelief.search(sensor.id, source=source, most_recent_beliefs_only=False),
+        TimedBelief.search(sensor.name, source=source, most_recent_beliefs_only=False),
+        sensor.search_beliefs(source=source, most_recent_beliefs_only=False),
+        tb.BeliefsDataFrame(sensor.beliefs)[
+            tb.BeliefsDataFrame(sensor.beliefs).index.get_level_values("source")
+            == source
+        ],
     ]
     for bdf in bdfs:
-        assert sensor.event_resolution == timedelta(
-            hours=0
-        )  # todo change to 1 after migrating Markets to Sensors
-        assert bdf.event_resolution == timedelta(
-            hours=0
-        )  # todo change to 1 after migrating Markets to Sensors
+        assert sensor.event_resolution == timedelta(hours=1)
+        assert bdf.event_resolution == timedelta(hours=1)
         assert len(bdf) == setup_beliefs
 
 
-def test_persist_beliefs(setup_beliefs):
+def test_persist_beliefs(setup_beliefs, setup_test_data):
     """Check whether persisting beliefs works.
 
     We load the already set up beliefs, and form new beliefs an hour later.
     """
     sensor = Sensor.query.filter_by(name="epex_da").one_or_none()
-    bdf: tb.BeliefsDataFrame = TimedBelief.search(sensor)
+    source = DataSource.query.filter_by(name="ENTSO-E").one_or_none()
+    bdf: tb.BeliefsDataFrame = TimedBelief.search(
+        sensor, source=source, most_recent_beliefs_only=False
+    )
 
     # Form new beliefs
     df = bdf.reset_index()
@@ -255,5 +268,7 @@ def test_persist_beliefs(setup_beliefs):
     )
 
     TimedBelief.add(bdf)
-    bdf: tb.BeliefsDataFrame = TimedBelief.search(sensor)
+    bdf: tb.BeliefsDataFrame = TimedBelief.search(
+        sensor, source=source, most_recent_beliefs_only=False
+    )
     assert len(bdf) == setup_beliefs * 2
