@@ -6,9 +6,10 @@ from flask_classful import FlaskView
 from flask_wtf import FlaskForm
 from wtforms import StringField, FloatField, DateTimeField, BooleanField
 from wtforms.validators import DataRequired
-from flask_security import roles_required
+from flask_security import roles_required, login_required
 
-from flexmeasures.data.config import db
+from flexmeasures.auth.policy import ADMIN_ROLE
+from flexmeasures.data import db
 from flexmeasures.data.models.user import User, Role, Account
 from flexmeasures.data.services.users import (
     get_user,
@@ -75,29 +76,31 @@ class UserCrudUI(FlaskView):
     route_base = "/users"
     trailing_slash = False
 
-    @roles_required("admin")
+    @roles_required(ADMIN_ROLE)
     def index(self):
         """/users"""
         include_inactive = request.args.get("include_inactive", "0") != "0"
-        get_users_response = InternalApi().get(
-            url_for(
-                "flexmeasures_api_v2_0.get_users", include_inactive=include_inactive
+        users = []
+        for account in Account.query.all():
+            get_users_response = InternalApi().get(
+                url_for(
+                    "UserAPI:index",
+                    account_id=account.id,
+                    include_inactive=include_inactive,
+                )
             )
-        )
-        users = [
-            process_internal_api_response(user, make_obj=True)
-            for user in get_users_response.json()
-        ]
+            users += [
+                process_internal_api_response(user, make_obj=True)
+                for user in get_users_response.json()
+            ]
         return render_flexmeasures_template(
             "crud/users.html", users=users, include_inactive=include_inactive
         )
 
-    @roles_required("admin")
+    @roles_required(ADMIN_ROLE)
     def get(self, id: str):
         """GET from /users/<id>"""
-        get_user_response = InternalApi().get(
-            url_for("flexmeasures_api_v2_0.get_user", id=id)
-        )
+        get_user_response = InternalApi().get(url_for("UserAPI:get", id=id))
         user: User = process_internal_api_response(
             get_user_response.json(), make_obj=True
         )
@@ -109,12 +112,12 @@ class UserCrudUI(FlaskView):
             asset_count = len(get_users_assets_response.json())
         return render_user(user, asset_count=asset_count)
 
-    @roles_required("admin")
+    @roles_required(ADMIN_ROLE)
     def toggle_active(self, id: str):
         """Toggle activation status via /users/toggle_active/<id>"""
         user: User = get_user(id)
         user_response = InternalApi().patch(
-            url_for("flexmeasures_api_v2_0.patch_user", id=id),
+            url_for("UserAPI:patch", id=id),
             args={"active": not user.active},
         )
         patched_user: User = process_internal_api_response(
@@ -126,17 +129,18 @@ class UserCrudUI(FlaskView):
             % (patched_user.username, patched_user.active),
         )
 
-    @roles_required("admin")
+    @login_required
     def reset_password_for(self, id: str):
         """/users/reset_password_for/<id>
         Set the password to something random (in case of worries the password might be compromised)
         and send instructions on how to reset."""
         user: User = get_user(id)
         InternalApi().patch(
-            url_for("flexmeasures_api_v2_0.reset_user_password", id=id),
+            url_for("UserAPI:reset_user_password", id=id),
         )
         return render_user(
             user,
             msg="The user's password has been changed to a random password"
-            " and password reset instructions have been sent to the user.",
+            " and password reset instructions have been sent to the user."
+            " Cookies and the API access token have also been invalidated.",
         )
